@@ -29,8 +29,12 @@ You can also adjust the configuration of individual instances by passing
 unexpected results. See `Customizing the Parser <customize.html>`_.
 """
 from __future__ import unicode_literals
-import collections
 import sys
+try:
+    # Python 3.3+
+    from collections.abc import Set
+except ImportError:
+    from collections import Set
 
 from nameparser.util import binary_type
 from nameparser.util import lc
@@ -45,10 +49,10 @@ from nameparser.config.regexes import REGEXES
 
 DEFAULT_ENCODING = 'UTF-8'
 
-class SetManager(collections.Set):
+class SetManager(Set):
     '''
     Easily add and remove config variables per module or instance. Subclass of
-    ``collections.Set``.
+    ``collections.abc.Set``.
     
     Only special functionality beyond that provided by set() is
     to normalize constants for comparison (lower case, no periods)
@@ -179,8 +183,37 @@ class Constants(object):
         'John'
         
     """
-    
-    
+    capitalize_name = False
+    """
+    If set, applies :py:meth:`~nameparser.parser.HumanName.capitalize` to
+    :py:class:`~nameparser.parser.HumanName` instance.
+
+    .. doctest::
+
+        >>> from nameparser.config import CONSTANTS
+        >>> CONSTANTS.capitalize_name = True
+        >>> name = HumanName("bob v. de la macdole-eisenhower phd")
+        >>> str(name)
+        'Bob V. de la MacDole-Eisenhower Ph.D.'
+
+    """
+    force_mixed_case_capitalization = False
+    """
+    If set, forces the capitalization of mixed case strings when
+    :py:meth:`~nameparser.parser.HumanName.capitalize` is called.
+
+    .. doctest::
+
+        >>> from nameparser.config import CONSTANTS
+        >>> CONSTANTS.force_mixed_case_capitalization = True
+        >>> name = HumanName('Shirley Maclaine')
+        >>> name.capitalize()
+        >>> str(name)
+        'Shirley MacLaine'
+
+    """
+
+
     def __init__(self, 
                     prefixes=PREFIXES, 
                     suffix_acronyms=SUFFIX_ACRONYMS,
