@@ -40,7 +40,7 @@ except AttributeError:
 
 class HumanNameTestBase(unittest.TestCase):
     def m(self, actual, expected, hn):
-        """assertEquals with a better message and awareness of hn.C.empty_attribute_default"""
+        """assertEqual with a better message and awareness of hn.C.empty_attribute_default"""
         expected = expected or hn.C.empty_attribute_default
         try:
             self.assertEqual(actual, expected, "'%s' != '%s' for '%s'\n%r" % (
@@ -50,7 +50,7 @@ class HumanNameTestBase(unittest.TestCase):
                 hn
             ))
         except UnicodeDecodeError:
-            self.assertEquals(actual, expected)
+            self.assertEqual(actual, expected)
 
 
 class HumanNamePythonTests(HumanNameTestBase):
@@ -62,8 +62,6 @@ class HumanNamePythonTests(HumanNameTestBase):
 
     def test_string_output(self):
         hn = HumanName("de la Véña, Jüan")
-        print(hn)
-        print(repr(hn))
 
     def test_escaped_utf8_bytes(self):
         hn = HumanName(b'B\xc3\xb6ck, Gerald')
@@ -1267,7 +1265,7 @@ class ConstantsCustomization(HumanNameTestBase):
     def test_add_title(self):
         hn = HumanName("Te Awanui-a-Rangi Black", constants=None)
         start_len = len(hn.C.titles)
-        self.assert_(start_len > 0)
+        self.assertTrue(start_len > 0)
         hn.C.titles.add('te')
         self.assertEqual(start_len + 1, len(hn.C.titles))
         hn.parse_full_name()
@@ -1278,7 +1276,7 @@ class ConstantsCustomization(HumanNameTestBase):
     def test_remove_title(self):
         hn = HumanName("Hon Solo", constants=None)
         start_len = len(hn.C.titles)
-        self.assert_(start_len > 0)
+        self.assertTrue(start_len > 0)
         hn.C.titles.remove('hon')
         self.assertEqual(start_len - 1, len(hn.C.titles))
         hn.parse_full_name()
@@ -1729,19 +1727,7 @@ class SuffixesTestCase(HumanNameTestBase):
         hn = HumanName("Ma, Jack")
         self.m(hn.first, "Jack", hn)
         self.m(hn.last, "Ma", hn)
-    
-    def test_potential_suffix_that_is_also_first_name_comma(self):
-        hn = HumanName("Johnson, Bart")
-        self.m(hn.first, "Bart", hn)
-        self.m(hn.last, "Johnson", hn)
-    
-    # TODO: handle conjunctions in last names followed by first names clashing with suffixes
-    @unittest.expectedFailure
-    def test_potential_suffix_that_is_also_first_name_comma_with_conjunction(self):
-        hn = HumanName("De la Vina, Bart")
-        self.m(hn.first, "Bart", hn)
-        self.m(hn.last, "De la Vina", hn)
-    
+
     def test_potential_suffix_that_is_also_last_name_with_suffix(self):
         hn = HumanName("Jack Ma Jr")
         self.m(hn.first, "Jack", hn)
@@ -2090,6 +2076,28 @@ class HumanNameOutputFormatTests(HumanNameTestBase):
         self.assertEqual(u(hn), "TEST2")
         CONSTANTS.string_format = _orig
 
+    def test_capitalize_name_constants_attribute(self):
+        from nameparser.config import CONSTANTS
+        CONSTANTS.capitalize_name = True
+        hn = HumanName("bob v. de la macdole-eisenhower phd")
+        self.assertEqual(str(hn), "Bob V. de la MacDole-Eisenhower Ph.D.")
+        CONSTANTS.capitalize_name = False
+
+    def test_force_mixed_case_capitalization_constants_attribute(self):
+        from nameparser.config import CONSTANTS
+        CONSTANTS.force_mixed_case_capitalization = True
+        hn = HumanName('Shirley Maclaine')
+        hn.capitalize()
+        self.assertEqual(str(hn), "Shirley MacLaine")
+        CONSTANTS.force_mixed_case_capitalization = False
+
+    def test_capitalize_name_and_force_mixed_case_capitalization_constants_attributes(self):
+        from nameparser.config import CONSTANTS
+        CONSTANTS.capitalize_name = True
+        CONSTANTS.force_mixed_case_capitalization = True
+        hn = HumanName('Shirley Maclaine')
+        self.assertEqual(str(hn), "Shirley MacLaine")
+
     def test_quote_nickname_formating(self):
         hn = HumanName("Rev John A. Kenneth Doe III (Kenny)")
         hn.string_format = "{title} {first} {middle} {last} {suffix} '{nickname}'"
